/*
 * JBrowsePlugin.java - Java Browser Plugin
 *
 * Copyright (c) 1999-2000 George Latkiewicz, Andre Kaplan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


import java.awt.Cursor;

import java.util.Vector;

import org.gjt.sp.jedit.EBMessage;
import org.gjt.sp.jedit.EBPlugin;
import org.gjt.sp.jedit.EditBus;
import org.gjt.sp.jedit.GUIUtilities;
import org.gjt.sp.jedit.jEdit;
import org.gjt.sp.jedit.View;
import org.gjt.sp.jedit.gui.DockableWindow;
import org.gjt.sp.jedit.gui.OptionsDialog;
import org.gjt.sp.jedit.msg.CreateDockableWindow;

import org.gjt.sp.util.Log;


/**
 * This class implements the jEdit's EBPlugin interface for the JBrowse plugin.
 * Responsible for creating dockable JBrowse.
 * @author George Latkiewicz
 * @author Andre Kaplan
 * @version $Id: JBrowsePlugin.java,v 1.8 2001/01/18 18:04:33 akaplan Exp $
**/
public class JBrowsePlugin extends EBPlugin
{
    /**
     * The 'name' of the dockable window.
    **/
    public static final String DOCKABLE_NAME = "jbrowse-dockable";


    public void start() {
        EditBus.addToNamedList(DockableWindow.DOCKABLE_WINDOW_LIST, DOCKABLE_NAME);
    }


    public void stop() {}


    public void createMenuItems(Vector menuItems)
    {
        menuItems.addElement(GUIUtilities.loadMenu("jbrowse-menu"));
    }


    /**
     * Adds the JBrowse options the the Global Options dialog
    **/
    public void createOptionPanes(OptionsDialog od)
    {
        od.addOptionPane(new JBrowseOptionPane());
    }


    public String getName() { return "JBrowse"; }


    public void handleMessage(EBMessage msg) {
        if (msg instanceof CreateDockableWindow) {
            CreateDockableWindow cmsg = (CreateDockableWindow) msg;
            if (cmsg.getDockableWindowName().equals(DOCKABLE_NAME)) {
                cmsg.setDockableWindow(new JBrowseDockable(cmsg.getView()));
            }
        }
    }


    public static void openJBrowseFor(View view) {
        Cursor savedCursor = null;

        try {
            // Check if the current buffer is a java buffer
            try {
                String bufferName = view.getBuffer().getName();
                if (!bufferName.toLowerCase().endsWith(".java")) {
                    GUIUtilities.error(
                        view,
                        "jbrowse.msg.notAJavaBuffer",
                        new Object[] { bufferName }
                    );
                    // No need to go further
                    return;
                }
            } catch (NullPointerException npe) {
                Log.log(Log.ERROR, JBrowsePlugin.class, npe);
            }

            // Set Wait Cursor
            savedCursor = view.getCursor();
            view.setCursor(new Cursor(Cursor.WAIT_CURSOR));

            // Build and Display a JBrowse GUI
            // Keep track of JBrowse <-> view assoc?
            new JBrowseDialog(view);

        } catch (Exception e) {
            Log.log(Log.DEBUG, JBrowsePlugin.class, e);
        } finally {
            if (savedCursor != null) {
                view.setCursor(savedCursor);
            } else {
                view.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
            }
        }
    }
}


/*
 * ChangeLog:
 * $Log: JBrowsePlugin.java,v $
 * Revision 1.8  2001/01/18 18:04:33  akaplan
 * Updated for jEdit 3.0, converted to UNIX line endings, some bugs corrected, JBrowse.Activator and JEditActivator removed
 *
 * Revision 1.5  2001/01/18 14:23:06  andre
 * JBrowse.Activator and JEditActivator removed
 *
 * Revision 1.4  2001/01/08 14:32:27  andre
 * Converted line endings to UNIX
 *
 * Revision 1.3  2001/01/08 14:18:13  andre
 * Updated for jEdit 3.0final
 *
 * Revision 1.2  2000/11/19 15:03:18  andre
 * Doc updates, props updates and  small code cleanings for JBrowse 1.3.2
 *
 * Revision 1.1.1.1  2000/11/12 14:31:21  andre
 * JBrowse 1.3.1 initial import
 *
 * Revision 1.6  2000/09/11 00:30:44  akaplan
 * Automatic reparse was broken when a new buffer was loaded
 *
 * Revision 1.5  2000/09/03 16:25:22  akaplan
 * Dockable API support, PluginHolder no longer supported
 *
 * Revision 1.4  2000/09/02 22:51:46  akaplan
 * JBrowse 1.2: added sort option, automatic reparse feature, important internal changes, see Change_History.html for details
 *
*/
