/*
 * JBrowseStatusPane.java - JBrowse status panel
 *
 * Copyright (c) 1999-2000 George Latkiewicz, Andre Kaplan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


import java.awt.Font;
import java.awt.GridLayout;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;


/**
 * JBrowse status panel
 * @author George Latkiewicz
 * @author Andre Kaplan
 * @version $Id: JBrowseStatusPane.java,v 1.3 2001/01/18 18:04:33 akaplan Exp $
**/
public class JBrowseStatusPane extends JPanel
{
    private JLabel classLabel;
    private JLabel interfaceLabel;
    private JLabel attributeLabel;
    private JLabel methodLabel;


    public JBrowseStatusPane() {
        this.setLayout(new GridLayout(1, 4, 0, 1));
        classLabel     = new JLabel(UML.Type.CLASS.getIcon());
        interfaceLabel = new JLabel(UML.Type.INTERFACE.getIcon());
        attributeLabel = new JLabel(UML.Type.ATTRIBUTE.getIcon());
        methodLabel    = new JLabel(UML.Type.METHOD.getIcon());

        classLabel.setIconTextGap(2);
        interfaceLabel.setIconTextGap(2);
        attributeLabel.setIconTextGap(2);
        methodLabel.setIconTextGap(2);

        classLabel.setToolTipText("classes");
        interfaceLabel.setToolTipText("interfaces");
        attributeLabel.setToolTipText("attributes");
        methodLabel.setToolTipText("methods");

        classLabel.setBorder(BorderFactory.createEtchedBorder());
        interfaceLabel.setBorder(BorderFactory.createEtchedBorder());
        attributeLabel.setBorder(BorderFactory.createEtchedBorder());
        methodLabel.setBorder(BorderFactory.createEtchedBorder());

        Font monoFont = new Font("Monospaced", Font.PLAIN, 11);

        classLabel.setFont(monoFont);
        interfaceLabel.setFont(monoFont);
        attributeLabel.setFont(monoFont);
        methodLabel.setFont(monoFont);

        this.add(classLabel);
        this.add(interfaceLabel);
        this.add(attributeLabel);
        this.add(methodLabel);
    }


    public void showResults(JBrowseParser.Results results) {
        if (results != null) { // required until File parser is implemented?
            // Update Status Bar
            this.classLabel.setText(    "" + results.getClassCount());
            this.interfaceLabel.setText("" + results.getInterfaceCount());
            this.attributeLabel.setText(
                "" + (results.getObjAttrCount() + results.getPrimAttrCount())
            );
            this.methodLabel.setText(   "" + results.getMethodCount() );
        }
    }
}


/*
 * ChangeLog:
 * $Log: JBrowseStatusPane.java,v $
 * Revision 1.3  2001/01/18 18:04:33  akaplan
 * Updated for jEdit 3.0, converted to UNIX line endings, some bugs corrected, JBrowse.Activator and JEditActivator removed
 *
 * Revision 1.2  2001/01/08 15:26:33  andre
 * Code cleanings
 *
 * Revision 1.1.1.1  2000/11/12 14:31:21  andre
 * JBrowse 1.3.1 initial import
 *
 * Revision 1.1  2000/09/02 22:34:57  akaplan
 * Action and Status panes moved outside JBrowse
 *
*/
