/*
 * Options.java - Options for JBrowse
 *
 * Copyright (c) 1999-2000 George Latkiewicz, Andre Kaplan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


/**
 * JBrowse Options
 * @author George Latkiewicz
 * @author Andre Kaplan
 * @version $Id: Options.java,v 1.5 2001/01/18 18:04:33 akaplan Exp $
**/
public class Options
{
    private boolean showStatusBar;
    private boolean automaticParse;
    private boolean sort;

    private Filter filterOpt;   // (WHAT to display)
    private Display displayOpt; // (HOW  to display)


    public Options()
    {
        filterOpt  = new Filter();
        displayOpt = new Display();

    } // Options(): <init>


    /**
     * The method that sets the option object's state to reflect the values
     * specified by the passed PropertyAccessor.
     */
    public void load(PropertyAccessor props)
    {
        // General Options
        setShowStatusBar(
            props.getBooleanProperty("jbrowse.showStatusBar", true));
        setAutomaticParse(
            props.getBooleanProperty("jbrowse.automaticParse", false));
        setSort(
            props.getBooleanProperty("jbrowse.sort", false));

        // Filter Options
        filterOpt.setShowAttributes(
            props.getBooleanProperty("jbrowse.showAttr"));
        filterOpt.setShowPrimitives(
            props.getBooleanProperty("jbrowse.showPrimAttr"));
        filterOpt.setShowGeneralizations(
            props.getBooleanProperty("jbrowse.showGeneralizations"));
        filterOpt.setShowThrows(
            props.getBooleanProperty("jbrowse.showThrows"));

        int topLevelVisIndex;
        try {
            topLevelVisIndex = Integer.parseInt(
                    props.getProperty("jbrowse.topLevelVisIndex"));
        } catch(NumberFormatException nf) {
            topLevelVisIndex = RWModifier.TOPLEVEL_VIS_PACKAGE;
        }
        if (topLevelVisIndex < RWModifier.TOPLEVEL_VIS_PACKAGE
                || topLevelVisIndex > RWModifier.TOPLEVEL_VIS_PUBLIC ) {
            topLevelVisIndex = RWModifier.TOPLEVEL_VIS_PACKAGE;
        }
        filterOpt.setTopLevelVisIndex( topLevelVisIndex );

        int memberVisIndex;
        try {
            memberVisIndex = Integer.parseInt(
                    props.getProperty("jbrowse.memberVisIndex"));
        } catch(NumberFormatException nf) {
            memberVisIndex = RWModifier.MEMBER_VIS_PRIVATE;
        }
        if (memberVisIndex < RWModifier.MEMBER_VIS_PRIVATE
                || memberVisIndex > RWModifier.MEMBER_VIS_PUBLIC ) {
            memberVisIndex = RWModifier.MEMBER_VIS_PRIVATE;
        }
        filterOpt.setMemberVisIndex( memberVisIndex );

        // Display Options
        displayOpt.setShowArguments(
                props.getBooleanProperty("jbrowse.showArgs"));
        displayOpt.setShowArgumentNames(
                props.getBooleanProperty("jbrowse.showArgNames"));
        displayOpt.setShowNestedName(
                props.getBooleanProperty("jbrowse.showNestedName"));
        displayOpt.setShowIconKeywords(
                props.getBooleanProperty("jbrowse.showIconKeywords"));
        displayOpt.setShowMiscMod(
                props.getBooleanProperty("jbrowse.showMiscMod"));
        displayOpt.setShowLineNum(
                props.getBooleanProperty("jbrowse.showLineNums"));

        int styleIndex;
        try
        {
            styleIndex = Integer.parseInt(
                    props.getProperty("jbrowse.displayStyle"));
        }
        catch(NumberFormatException nf)
        {
            styleIndex = Options.Display.STYLE_UML;
        }
        if (styleIndex < Options.Display.STYLE_FIRST
                || styleIndex > Options.Display.STYLE_LAST ) {
            styleIndex = Options.Display.STYLE_UML;
        }
        displayOpt.setStyleIndex( styleIndex );

        displayOpt.setVisSymbols(
                props.getBooleanProperty("jbrowse.custVisAsSymbol"));
        displayOpt.setAbstractItalic(
                props.getBooleanProperty("jbrowse.custAbsAsItalic"));
        displayOpt.setStaticUlined(
                props.getBooleanProperty("jbrowse.custStaAsUlined"));
        displayOpt.setTypeIsSuffixed(
                props.getBooleanProperty("jbrowse.custTypeIsSuffixed"));

    } // load(PropertyAccessor props): void


    /**
     * The method that sets the passed PropertyAccessor's state to reflect
     * the current state of this Options object.
     */
    public void save(PropertyAccessor props)
    {
        // General Options
        //----------------
        props.setBooleanProperty( "jbrowse.showStatusBar", getShowStatusBar());
        props.setBooleanProperty( "jbrowse.automaticParse", getAutomaticParse());
        props.setBooleanProperty( "jbrowse.sort", getSort());


        // Filter Options
        //---------------
        props.setBooleanProperty( "jbrowse.showAttr",
                filterOpt.getShowAttributes());
        props.setBooleanProperty( "jbrowse.showPrimAttr",
                filterOpt.getShowPrimitives());
        props.setBooleanProperty( "jbrowse.showGeneralizations",
                filterOpt.getShowGeneralizations());
        props.setBooleanProperty( "jbrowse.showThrows",
                filterOpt.getShowThrows());

        /* Visibility Level */
        props.setProperty( "jbrowse.topLevelVisIndex",
                String.valueOf(filterOpt.getTopLevelVisIndex()) );
        props.setProperty( "jbrowse.memberVisIndex",
                String.valueOf(filterOpt.getMemberVisIndex()) );


        // Display Options
        //----------------
        props.setBooleanProperty( "jbrowse.showArgs",
                displayOpt.getShowArguments());
        props.setBooleanProperty( "jbrowse.showArgNames",
                displayOpt.getShowArgumentNames());
        props.setBooleanProperty( "jbrowse.showNestedName",
                displayOpt.getShowNestedName());
        props.setBooleanProperty( "jbrowse.showIconKeywords",
                displayOpt.getShowIconKeywords());
        props.setBooleanProperty( "jbrowse.showMiscMod",
                displayOpt.getShowMiscMod());
        props.setBooleanProperty( "jbrowse.showLineNums",
                displayOpt.getShowLineNum());

        /* Display Style */
        props.setProperty("jbrowse.displayStyle",
                String.valueOf(displayOpt.getStyleIndex()) );

        /* Custom Style Options */
        props.setBooleanProperty("jbrowse.custVisAsSymbol",
                displayOpt.getVisSymbols());
        props.setBooleanProperty("jbrowse.custAbsAsItalic",
                displayOpt.getAbstractItalic());
        props.setBooleanProperty("jbrowse.custStaAsUlined",
                displayOpt.getStaticUlined());
        props.setBooleanProperty("jbrowse.custTypeIsSuffixed",
                displayOpt.getTypeIsSuffixed());

    } // save(PropertyAccessor props): void


    public final boolean getShowStatusBar()  { return showStatusBar; }


    public final void setShowStatusBar(boolean flag) {
        showStatusBar = flag;
    }


    public final boolean getAutomaticParse()  { return automaticParse; }


    public final void setAutomaticParse(boolean flag) {
        automaticParse = flag;
    }


    public final boolean getSort()  { return sort; }


    public final void setSort(boolean flag) {
        sort = flag;
    }


    public final Filter  getFilterOptions()  { return filterOpt; }


    public final Display getDisplayOptions() { return displayOpt; }


    public final String toString()
    {
        return  filterOpt.toString() + "\n"
                + displayOpt.toString();
    }


    public static class Display implements DisplayIro
    {
        // Display Style options (HOW)

        private boolean showArguments;
        private boolean showArgumentNames;
        private boolean showNestedName;
        private boolean showIconKeywords;
        private boolean showMiscMod;
        private boolean showLineNum;

        private int styleIndex = STYLE_UML;

        private boolean visSymbols;
        private boolean abstractItalic;
        private boolean staticUlined;
        private boolean typeIsSuffixed;


        public final boolean getShowArguments()     { return showArguments; }
        public final boolean getShowArgumentNames() { return showArgumentNames; }
        public final boolean getShowNestedName()    { return showNestedName; }
        public final boolean getShowIconKeywords()  { return showIconKeywords; }
        public final boolean getShowMiscMod()       { return showMiscMod; }
        public final boolean getShowLineNum()       { return showLineNum; }

        public final int getStyleIndex()            { return styleIndex; }

        public final boolean getVisSymbols()        { return visSymbols; }
        public final boolean getAbstractItalic()    { return abstractItalic; }
        public final boolean getStaticUlined()      { return staticUlined; }
        public final boolean getTypeIsSuffixed()    { return typeIsSuffixed; }


        public final void setShowArguments(boolean flag)
        {
            showArguments = flag;
        }


        public final void setShowArgumentNames(boolean flag)
        {
            showArgumentNames = flag;
        }


        public final void setShowNestedName(boolean flag)
        {
            showNestedName = flag;
        }


        public final void setShowIconKeywords(boolean flag)
        {
            showIconKeywords = flag;
        }


        public final void setShowMiscMod(boolean flag)
        {
            showMiscMod = flag;
        }


        public final void setShowLineNum(boolean flag)
        {
            showLineNum = flag;
        }


        public final void setStyleIndex(int index)
        {
            styleIndex = index;
        }


        public final void setVisSymbols(boolean flag)
        {
            visSymbols = flag;
        }


        public final void setAbstractItalic(boolean flag)
        {
            abstractItalic = flag;
        }


        public final void setStaticUlined(boolean flag)
        {
            staticUlined = flag;
        }


        public final void setTypeIsSuffixed(boolean flag)
        {
            typeIsSuffixed = flag;
        }


        public final DisplayIro getInverseOptions() {
            Display inverseOpt = new Display();

            inverseOpt.showArguments     = !showArguments;
            inverseOpt.showArgumentNames = !showArgumentNames;
            inverseOpt.showNestedName    = !showNestedName;
            inverseOpt.showIconKeywords  = !showIconKeywords;
            inverseOpt.showMiscMod       = !showMiscMod;
            inverseOpt.showLineNum       = !showLineNum;

            inverseOpt.visSymbols      = !visSymbols;
            inverseOpt.abstractItalic  = !abstractItalic;
            inverseOpt.staticUlined    = !staticUlined;
            inverseOpt.typeIsSuffixed  = !typeIsSuffixed;

            if (styleIndex == STYLE_UML) {
                inverseOpt.styleIndex = STYLE_JAVA;
            } else if (styleIndex == STYLE_JAVA) {
                inverseOpt.styleIndex = STYLE_UML;
            }

            return inverseOpt;
        }


        public String toString()
        {
            return  "How to display:"
                    + "\n\tshowArguments     = " + showArguments
                    + "\n\tshowArgumentNames = " + showArgumentNames
                    + "\n\tshowNestedName    = " + showNestedName
                    + "\n\tshowIconKeywords  = " + showIconKeywords
                    + "\n\tshowMiscMod       = " + showMiscMod
                    + "\n\tshowLineNum       = " + showLineNum

                    + "\n\tstyleIndex        = " + styleIndex

                    + "\n\tvisSymbols        = " + visSymbols
                    + "\n\tabstractItalic    = " + abstractItalic
                    + "\n\tstaticUlined      = " + staticUlined
                    + "\n\ttypeIsSuffixed    = " + typeIsSuffixed;

        } // toString(): String
    } // class Options.Display implements Options.DisplayIro


    /**
     * Options.DisplayIro - Interface for Accessing Display options for JBrowse
     */
    public static interface DisplayIro
    {
        // Display Style options (HOW)

        // constants - for styleIndex
        static final int STYLE_FIRST  = 0;
        static final int STYLE_UML    = 0;
        static final int STYLE_JAVA   = 1;
        static final int STYLE_CUSTOM = 2;
        static final int STYLE_LAST   = 2;


        public boolean getShowArguments();
        public boolean getShowArgumentNames();
        public boolean getShowNestedName();
        public boolean getShowIconKeywords();
        public boolean getShowMiscMod();
        public boolean getShowLineNum();


        public int getStyleIndex();


        public boolean getVisSymbols();
        public boolean getAbstractItalic();
        public boolean getStaticUlined();
        public boolean getTypeIsSuffixed();


        public DisplayIro getInverseOptions();
    } // interface Options.DisplayIro


    public static class Filter implements FilterIro
    {
        // Filter options (WHAT)

        private boolean showAttributes;
        private boolean showPrimitives;
        private boolean showGeneralizations;
        private boolean showThrows;

        private int topLevelVisIndex = 0;
        private int memberVisIndex   = 0;


        public final boolean getShowAttributes()      { return showAttributes; }
        public final boolean getShowPrimitives()      { return showPrimitives; }
        public final boolean getShowGeneralizations() { return showGeneralizations; }
        public final boolean getShowThrows()          { return showThrows; }


        public final int getTopLevelVisIndex()   { return topLevelVisIndex; }
        public final int getMemberVisIndex()     { return memberVisIndex; }


        public final void setShowAttributes(boolean flag)
        {
            showAttributes = flag;
        }


        public final void setShowPrimitives(boolean flag)
        {
            showPrimitives = flag;
        }


        public final void setShowGeneralizations(boolean flag)
        {
            showGeneralizations = flag;
        }


        public final void setShowThrows(boolean flag)
        {
            showThrows = flag;
        }


        public final void setTopLevelVisIndex(int level)
        {
            topLevelVisIndex = level;
        }


        public final void setMemberVisIndex(int level)
        {
            memberVisIndex = level;
        }


        public String toString()
        {
            return    "What to include:"
                    + "\n\tshowAttributes      = " + showAttributes
                    + "\n\tshowPrimitives      = " + showPrimitives
                    + "\n\tshowGeneralizations = " + showGeneralizations
                    + "\n\tshowThrows          = " + showThrows

                    + "\n\ttopLevelVisIndex    = " + topLevelVisIndex
                    + "\n\tmemberVisIndex      = " + memberVisIndex;

        } // toString(): String
    } // class Options.Filter implements Options.FilterIro {


    /**
     *  FilterIro - Interface for Accessing Filter options for JBrowse
     */
    public static interface FilterIro
    {
        // Filter options (WHAT)

        public boolean getShowAttributes();
        public boolean getShowPrimitives();
        public boolean getShowGeneralizations();
        public boolean getShowThrows();

        public int getTopLevelVisIndex();
        public int getMemberVisIndex();

    } // interface Options.FilterIro
} // public class Options


/*
 * ChangeLog:
 * $Log: Options.java,v $
 * Revision 1.5  2001/01/18 18:04:33  akaplan
 * Updated for jEdit 3.0, converted to UNIX line endings, some bugs corrected, JBrowse.Activator and JEditActivator removed
 *
 * Revision 1.4  2001/01/08 15:48:12  andre
 * Final code cleanings
 *
 * Revision 1.3  2001/01/08 15:26:33  andre
 * Code cleanings
 *
 * Revision 1.2  2001/01/08 14:32:27  andre
 * Converted line endings to UNIX
 *
 * Revision 1.1.1.1  2000/11/12 14:31:21  andre
 * JBrowse 1.3.1 initial import
 *
 * Revision 1.3  2000/09/02 22:51:46  akaplan
 * JBrowse 1.2: added sort option, automatic reparse feature, important internal changes, see Change_History.html for details
 *
*/
