/*
 * UMLTreeSorter - Sorts an UMLTree
 * Copyright (c) 1999, 2000 Andre Kaplan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/


import org.gjt.sp.jedit.MiscUtilities;


/**
 * A class to sort UML trees
 * @author Andre Kaplan
**/
public class UMLTreeSorter
{
    /**
     * Sort siblings of a UML Tree Node.
     * <OL>
     *     <LI>All siblings are put in an array
     *     <LI>Removed from the current node
     *     <LI>The array is sorted
     *     <LI>The sorted nodes are put back into the tree
     * </OL>
    **/
    public static void sort(UMLTree.Node n, MiscUtilities.Compare c)
    {
        UMLTree.Node[] a = new UMLTree.Node[n.getChildCount()];

        for (int i = 0; i < n.getChildCount(); i++) {
            a[i] = (UMLTree.Node) n.getChildAt(i);
        }

        n.removeAllChildren();

        /* JDK1.2: Arrays.sort() */
        MiscUtilities.quicksort(a, c);

        for (int i = 0; i < a.length; i++) {
            n.add(a[i]);
        }
    }
}


/*
 * ChangeLog:
 * $Log: UMLTreeSorter.java,v $
 * Revision 1.3  2001/01/18 18:04:33  akaplan
 * Updated for jEdit 3.0, converted to UNIX line endings, some bugs corrected, JBrowse.Activator and JEditActivator removed
 *
 * Revision 1.4  2001/01/08 15:26:33  andre
 * Code cleanings
 *
 * Revision 1.3  2001/01/08 14:32:27  andre
 * Converted line endings to UNIX
 *
 * Revision 1.2  2000/11/19 12:49:17  andre
 * Fixed sort bug with JDK1.3 and Windows; changing the sort order doesn't collapse the JBrowse tree anymore
 *
 * Revision 1.1.1.1  2000/11/12 14:31:21  andre
 * JBrowse 1.3.1 initial import
 *
 * Revision 1.1  2000/09/02 22:41:20  akaplan
 * Sort UML Tree siblings
 *
*/

